@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class DjangoBibleConfig(AppConfig):
-    name = 'djangobible'
+    name = "djangobible"
